flika
=====

.. image:: flika/docs/_static/img/flika_screencapture.gif

**flika** is an interactive image processing program for biologists written in Python.


Website
-------
`flika-org.github.io <http://flika-org.github.io/>`_

Documentation
-------------
`flika-org.github.io/contents.html <http://flika-org.github.io/contents.html>`_

Install
-------
`flika-org.github.io/getting-started.html#installation <http://flika-org.github.io/getting-started.html#installation>`_

.. code:: python

	pip install flika
